@@ -24,7 +24,7 @@ COLUMNS_EXPECTED = ['name', 'role']
 
 
 def weave(
-    doc_root: str | pathlib.Path, structure_name: str, target_key: str, facet_key: str, options: dict[str, bool]
+    doc_root: str | pathlib.Path, structure_name: str, target_key: str, facet_key: str, options: dict[str, bool | str]
 ) -> int:
     """Later alligator."""
     separator = '- ' * 80
