@@ -2,10 +2,12 @@
 import datetime as dti
 import difflib
 import hashlib
+import io
 import os
 import pathlib
 import shutil
 import subprocess  # nosec B404
+import sys
 import time
 from typing import Any, Callable, no_type_check
 
@@ -16,10 +18,12 @@ from taksonomia.taksonomia import Taxonomy  # type: ignore
 
 import liitos.captions as cap
 import liitos.concat as con
+import liitos.description_lists as dsc
 import liitos.figures as fig
 import liitos.gather as gat
 import liitos.labels as lab
 import liitos.patch as pat
+import liitos.tables as tab
 from liitos import ENCODING, log
 
 DOC_BASE = pathlib.Path('..', '..')
@@ -123,7 +127,7 @@ def unified_diff(left: list[str], right: list[str], left_label: str = 'before',
 
 @no_type_check
 def der(
-    doc_root: str | pathlib.Path, structure_name: str, target_key: str, facet_key: str, options: dict[str, bool]
+    doc_root: str | pathlib.Path, structure_name: str, target_key: str, facet_key: str, options: dict[str, bool | str]
 ) -> int:
     """Later alligator."""
     log.info(LOG_SEPARATOR)
@@ -335,7 +339,7 @@ def der(
             log.info('post-action queue (from reference renaming) is empty - nothing to move')
         log.info(LOG_SEPARATOR)
 
-        fmt_spec = 'markdown+link_attributes'
+        fmt_spec = 'markdown+header_attributes+link_attributes+strikeout'
         in_doc = 'document.md'
         out_doc = 'document.tex'
         markdown_to_latex_command = [
@@ -352,7 +356,7 @@ def der(
             'mermaid-filter',
         ]
         log.info(LOG_SEPARATOR)
-        log.info('pandoc -f markdown+link_attributes -t latex document.md -o document.tex --filter mermaid-filter ...')
+        log.info(f'executing ({" ".join(markdown_to_latex_command)}) ...')
         process = subprocess.Popen(  # nosec B603
             markdown_to_latex_command, stdout=subprocess.PIPE, stderr=subprocess.STDOUT
         )
@@ -379,7 +383,8 @@ def der(
         log.info('diff of the (captions-below-tables) filter result:')
         log.info(LOG_SEPARATOR)
         for line in unified_diff(lines, lines_caps_patch):
-            log.info(line)
+            for fine in line.split('\n'):
+                log.info(fine)
         log.info(LOG_SEPARATOR)
 
         log.info(LOG_SEPARATOR)
@@ -393,7 +398,8 @@ def der(
         log.info('diff of the (inject-stem-derived-labels) filter result:')
         log.info(LOG_SEPARATOR)
         for line in unified_diff(lines_caps_patch, lines_inject_stem_label):
-            log.info(line)
+            for fine in line.split('\n'):
+                log.info(fine)
         log.info(LOG_SEPARATOR)
 
         log.info(LOG_SEPARATOR)
@@ -407,22 +413,62 @@ def der(
         log.info('diff of the (inject-scale-figures) filter result:')
         log.info(LOG_SEPARATOR)
         for line in unified_diff(lines_inject_stem_label, lines_scale_figures):
-            log.info(line)
+            for fine in line.split('\n'):
+                log.info(fine)
         log.info(LOG_SEPARATOR)
 
+        log.info(LOG_SEPARATOR)
+        log.info('add options to descriptions (definition lists) ...')
+        doc_before_descriptions_patch = 'document-before-description-options-patch.tex.txt'
+        with open(doc_before_descriptions_patch, 'wt', encoding=ENCODING) as handle:
+            handle.write('\n'.join(lines_scale_figures))
+        lines_description_options = dsc.options(lines_scale_figures)
+        with open('document.tex', 'wt', encoding=ENCODING) as handle:
+            handle.write('\n'.join(lines_description_options))
+        log.info('diff of the (inject-description-options) filter result:')
+        log.info(LOG_SEPARATOR)
+        for line in unified_diff(lines_scale_figures, lines_description_options):
+            for fine in line.split('\n'):
+                log.info(fine)
+        log.info(LOG_SEPARATOR)
+
+        if options.get('patch_tables', False):
+            log.info(LOG_SEPARATOR)
+            log.info('patching tables EXPERIMENTAL (table-shape) ...')
+            doc_before_table_shape_patch = 'document-before-table-shape-patch.tex.txt'
+            with open(doc_before_table_shape_patch, 'wt', encoding=ENCODING) as handle:
+                handle.write('\n'.join(lines_description_options))
+            lines_table_shape_options = tab.patch(lines_description_options)
+            with open('document.tex', 'wt', encoding=ENCODING) as handle:
+                handle.write('\n'.join(lines_table_shape_options))
+            log.info('diff of the (changed-table-shape) filter result:')
+            log.info(LOG_SEPARATOR)
+            for line in unified_diff(lines_description_options, lines_table_shape_options):
+                for fine in line.split('\n'):
+                    log.info(fine)
+            log.info(LOG_SEPARATOR)
+        else:
+            log.info(LOG_SEPARATOR)
+            log.info('not patching tables but commenting out (ignoring) any columns command (table-shape) ...')
+            lines_table_shape_options = [
+                f'%IGNORED_{v}' if v.startswith(r'\columns=') else v for v in lines_description_options
+            ]
+            log.info(LOG_SEPARATOR)
+
         if need_patching:
             log.info(LOG_SEPARATOR)
             log.info('apply user patches ...')
             doc_before_user_patch = 'document-before-user-patch.tex.txt'
             with open(doc_before_user_patch, 'wt', encoding=ENCODING) as handle:
-                handle.write('\n'.join(lines_scale_figures))
-            lines_user_patches = pat.apply(patches, lines_scale_figures)
+                handle.write('\n'.join(lines_table_shape_options))
+            lines_user_patches = pat.apply(patches, lines_table_shape_options)
             with open('document.tex', 'wt', encoding=ENCODING) as handle:
                 handle.write('\n'.join(lines_user_patches))
             log.info('diff of the (user-patches) filter result:')
             log.info(LOG_SEPARATOR)
-            for line in unified_diff(lines_scale_figures, lines_user_patches):
-                log.info(line)
+            for line in unified_diff(lines_table_shape_options, lines_user_patches):
+                for fine in line.split('\n'):
+                    log.info(fine)
             log.info(LOG_SEPARATOR)
         else:
             log.info(LOG_SEPARATOR)
@@ -468,6 +514,16 @@ def der(
         else:
             log.info(f'latex-to-pdf process 3/3  ({latex_to_pdf_command}) returned {return_code}')
 
+        if str(options.get('label', '')).strip():
+            labeling_call = str(options['label']).strip().split()
+            log.info(LOG_SEPARATOR)
+            log.info(f'Labeling the resulting pdf file per ({options["label"]})')
+            proc = subprocess.Popen(labeling_call, stdout=subprocess.PIPE)  # nosec B603
+            for line in io.TextIOWrapper(proc.stdout, encoding='utf-8'):
+                print(line.rstrip())
+            sys.stdout.flush()
+            log.info(LOG_SEPARATOR)
+
         log.info(LOG_SEPARATOR)
         log.info('Moving stuff around (result phase) ...')
         source_asset = 'this.pdf'
